@@ -39,5 +39,19 @@ def create_aussportsbetting_team_model(
         coaches=[],
         lbw=None,
         end_dt=None,
+        runs=None,
+        wickets=None,
+        overs=None,
+        balls=None,
+        byes=None,
+        leg_byes=None,
+        wides=None,
+        no_balls=None,
+        penalties=None,
+        balls_per_over=None,
+        fours=None,
+        sixes=None,
+        catches=None,
+        catches_dropped=None,
         version=version,
     )
