@@ -551,4 +551,16 @@ def create_espncricinfo_player_model(
         dots=dots,
         wides=wides,
         no_balls=no_balls,
+        free_throw_attempt_rate=None,
+        offensive_rebound_percentage=None,
+        defensive_rebound_percentage=None,
+        total_rebound_percentage=None,
+        assist_percentage=None,
+        steal_percentage=None,
+        block_percentage=None,
+        turnover_percentage=None,
+        usage_percentage=None,
+        offensive_rating=None,
+        defensive_rating=None,
+        box_plus_minus=None,
     )
