@@ -228,7 +228,9 @@ IG_FIELD = "4461"
 RICE_STADIUM = "21557"
 INDEPENDENCE_STADIUM = "3766"
 MEMORIAL_STADIUM = "16280"
+HUNTINGTON_BANK_FIELD = "19480"
 NFL_VENUE_IDENTITY_MAP = {
+    # SportsDB
     "18784": EMPOWER_FIELD,
     "28739": TOM_BENSOM_HALL_OF_FAME_STADIUM,
     "15812": METLIFE_STADIUM,
@@ -372,6 +374,7 @@ NFL_VENUE_IDENTITY_MAP = {
     "23848": SHEA_STADIUM,
     "17145": EMPOWER_FIELD,
     "30856": ATT_STADIUM,
+    "19480": HUNTINGTON_BANK_FIELD,
 }
 NFL_PLAYER_IDENTITY_MAP: dict[str, str] = {}
 
