@@ -1,7 +1,6 @@
 """Sports DB league model."""
 
 # pylint: disable=line-too-long
-import datetime
 import io
 from typing import Iterator
 
@@ -74,11 +73,12 @@ class SportsDBLeagueModel(LeagueModel):
                     year,
                     season_type,
                 )
-                pbar.set_description(
-                    f"SportsDB {season_year} - {season_type} - {game_model.dt}"
-                )
-                yield game_model
-                event_ids.add(game["idEvent"])
+                if game_model is not None:
+                    pbar.set_description(
+                        f"SportsDB {season_year} - {season_type} - {game_model.dt}"
+                    )
+                    yield game_model
+                    event_ids.add(game["idEvent"])
                 current_count = count
             response = self.session.get(
                 f"https://www.thesportsdb.com/season/{league_id}/{season_year}?csv=1&all=1",
@@ -116,17 +116,14 @@ class SportsDBLeagueModel(LeagueModel):
                         year,
                         season_type,
                     )
-                    pbar.set_description(
-                        f"SportsDB {season_year} - {season_type} - {game_model.dt}"
-                    )
-                    yield game_model
+                    if game_model is not None:
+                        pbar.set_description(
+                            f"SportsDB {season_year} - {season_type} - {game_model.dt}"
+                        )
+                        yield game_model
                     current_count += 1
 
-        if year < datetime.datetime.now().year - 1:
-            yield from internal_produce_games()
-        else:
-            with self.session.cache_disabled():
-                yield from internal_produce_games()
+        yield from internal_produce_games()
 
     @property
     def games(self) -> Iterator[GameModel]:
