@@ -245,6 +245,18 @@ def _create_sportsreference_player_model(
     tackles: dict[str, int],
     interceptions: dict[str, int],
     clearances: dict[str, int],
+    free_throw_attempt_rate: dict[str, float],
+    offensive_rebound_percentage: dict[str, float],
+    defensive_rebound_percentage: dict[str, float],
+    total_rebound_percentage: dict[str, float],
+    assist_percentage: dict[str, float],
+    steal_percentage: dict[str, float],
+    block_percentage: dict[str, float],
+    turnover_percentage: dict[str, float],
+    usage_percentage: dict[str, float],
+    offensive_rating: dict[str, int],
+    defensive_rating: dict[str, int],
+    box_plus_minus: dict[str, float],
 ) -> PlayerModel | None:
     """Create a player model from sports reference."""
     player_url = _fix_url(player_url)
@@ -797,6 +809,18 @@ def _create_sportsreference_player_model(
         dots=None,
         wides=None,
         no_balls=None,
+        free_throw_attempt_rate=free_throw_attempt_rate.get(name),
+        offensive_rebound_percentage=offensive_rebound_percentage.get(name),
+        defensive_rebound_percentage=defensive_rebound_percentage.get(name),
+        total_rebound_percentage=total_rebound_percentage.get(name),
+        assist_percentage=assist_percentage.get(name),
+        steal_percentage=steal_percentage.get(name),
+        block_percentage=block_percentage.get(name),
+        turnover_percentage=turnover_percentage.get(name),
+        usage_percentage=usage_percentage.get(name),
+        offensive_rating=offensive_rating.get(name),
+        defensive_rating=defensive_rating.get(name),
+        box_plus_minus=box_plus_minus.get(name),
     )
 
 
@@ -995,6 +1019,18 @@ def _cached_create_sportsreference_player_model(
     tackles: dict[str, int],
     interceptions: dict[str, int],
     clearances: dict[str, int],
+    free_throw_attempt_rate: dict[str, float],
+    offensive_rebound_percentage: dict[str, float],
+    defensive_rebound_percentage: dict[str, float],
+    total_rebound_percentage: dict[str, float],
+    assist_percentage: dict[str, float],
+    steal_percentage: dict[str, float],
+    block_percentage: dict[str, float],
+    turnover_percentage: dict[str, float],
+    usage_percentage: dict[str, float],
+    offensive_rating: dict[str, int],
+    defensive_rating: dict[str, int],
+    box_plus_minus: dict[str, float],
 ) -> PlayerModel | None:
     return _create_sportsreference_player_model(
         session=session,
@@ -1190,6 +1226,18 @@ def _cached_create_sportsreference_player_model(
         tackles=tackles,
         interceptions=interceptions,
         clearances=clearances,
+        free_throw_attempt_rate=free_throw_attempt_rate,
+        offensive_rebound_percentage=offensive_rebound_percentage,
+        defensive_rebound_percentage=defensive_rebound_percentage,
+        total_rebound_percentage=total_rebound_percentage,
+        assist_percentage=assist_percentage,
+        steal_percentage=steal_percentage,
+        block_percentage=block_percentage,
+        turnover_percentage=turnover_percentage,
+        usage_percentage=usage_percentage,
+        offensive_rating=offensive_rating,
+        defensive_rating=defensive_rating,
+        box_plus_minus=box_plus_minus,
     )
 
 
@@ -1386,6 +1434,18 @@ def create_sportsreference_player_model(
     tackles: dict[str, int],
     interceptions: dict[str, int],
     clearances: dict[str, int],
+    free_throw_attempt_rate: dict[str, float],
+    offensive_rebound_percentage: dict[str, float],
+    defensive_rebound_percentage: dict[str, float],
+    total_rebound_percentage: dict[str, float],
+    assist_percentage: dict[str, float],
+    steal_percentage: dict[str, float],
+    block_percentage: dict[str, float],
+    turnover_percentage: dict[str, float],
+    usage_percentage: dict[str, float],
+    offensive_rating: dict[str, int],
+    defensive_rating: dict[str, int],
+    box_plus_minus: dict[str, float],
 ) -> PlayerModel | None:
     """Create a player model from sports reference."""
     if not pytest_is_running.is_running():
@@ -1583,6 +1643,18 @@ def create_sportsreference_player_model(
             tackles=tackles,
             interceptions=interceptions,
             clearances=clearances,
+            free_throw_attempt_rate=free_throw_attempt_rate,
+            offensive_rebound_percentage=offensive_rebound_percentage,
+            defensive_rebound_percentage=defensive_rebound_percentage,
+            total_rebound_percentage=total_rebound_percentage,
+            assist_percentage=assist_percentage,
+            steal_percentage=steal_percentage,
+            block_percentage=block_percentage,
+            turnover_percentage=turnover_percentage,
+            usage_percentage=usage_percentage,
+            offensive_rating=offensive_rating,
+            defensive_rating=defensive_rating,
+            box_plus_minus=box_plus_minus,
         )
     with session.cache_disabled():
         return _create_sportsreference_player_model(
@@ -1779,4 +1851,16 @@ def create_sportsreference_player_model(
             tackles=tackles,
             interceptions=interceptions,
             clearances=clearances,
+            free_throw_attempt_rate=free_throw_attempt_rate,
+            offensive_rebound_percentage=offensive_rebound_percentage,
+            defensive_rebound_percentage=defensive_rebound_percentage,
+            total_rebound_percentage=total_rebound_percentage,
+            assist_percentage=assist_percentage,
+            steal_percentage=steal_percentage,
+            block_percentage=block_percentage,
+            turnover_percentage=turnover_percentage,
+            usage_percentage=usage_percentage,
+            offensive_rating=offensive_rating,
+            defensive_rating=defensive_rating,
+            box_plus_minus=box_plus_minus,
         )
