@@ -289,6 +289,18 @@ def _create_sportsreference_team_model(
     tackles: dict[str, int],
     interceptions: dict[str, int],
     clearances: dict[str, int],
+    free_throw_attempt_rate: dict[str, float],
+    offensive_rebound_percentage: dict[str, float],
+    defensive_rebound_percentage: dict[str, float],
+    total_rebound_percentage: dict[str, float],
+    assist_percentage: dict[str, float],
+    steal_percentage: dict[str, float],
+    block_percentage: dict[str, float],
+    turnover_percentage: dict[str, float],
+    usage_percentage: dict[str, float],
+    offensive_rating: dict[str, int],
+    defensive_rating: dict[str, int],
+    box_plus_minus: dict[str, float],
 ) -> TeamModel:
     if url in _BAD_TEAM_URLS:
         return TeamModel(
@@ -610,6 +622,18 @@ def _create_sportsreference_team_model(
                     tackles=tackles,
                     interceptions=interceptions,
                     clearances=clearances,
+                    free_throw_attempt_rate=free_throw_attempt_rate,
+                    offensive_rebound_percentage=offensive_rebound_percentage,
+                    defensive_rebound_percentage=defensive_rebound_percentage,
+                    total_rebound_percentage=total_rebound_percentage,
+                    assist_percentage=assist_percentage,
+                    steal_percentage=steal_percentage,
+                    block_percentage=block_percentage,
+                    turnover_percentage=turnover_percentage,
+                    usage_percentage=usage_percentage,
+                    offensive_rating=offensive_rating,
+                    defensive_rating=defensive_rating,
+                    box_plus_minus=box_plus_minus,
                 )
                 for x in valid_player_urls
             ]
@@ -841,6 +865,18 @@ def _cached_create_sportsreference_team_model(
     tackles: dict[str, int],
     interceptions: dict[str, int],
     clearances: dict[str, int],
+    free_throw_attempt_rate: dict[str, float],
+    offensive_rebound_percentage: dict[str, float],
+    defensive_rebound_percentage: dict[str, float],
+    total_rebound_percentage: dict[str, float],
+    assist_percentage: dict[str, float],
+    steal_percentage: dict[str, float],
+    block_percentage: dict[str, float],
+    turnover_percentage: dict[str, float],
+    usage_percentage: dict[str, float],
+    offensive_rating: dict[str, int],
+    defensive_rating: dict[str, int],
+    box_plus_minus: dict[str, float],
 ) -> TeamModel:
     return _create_sportsreference_team_model(
         session=session,
@@ -1038,6 +1074,18 @@ def _cached_create_sportsreference_team_model(
         tackles=tackles,
         interceptions=interceptions,
         clearances=clearances,
+        free_throw_attempt_rate=free_throw_attempt_rate,
+        offensive_rebound_percentage=offensive_rebound_percentage,
+        defensive_rebound_percentage=defensive_rebound_percentage,
+        total_rebound_percentage=total_rebound_percentage,
+        assist_percentage=assist_percentage,
+        steal_percentage=steal_percentage,
+        block_percentage=block_percentage,
+        turnover_percentage=turnover_percentage,
+        usage_percentage=usage_percentage,
+        offensive_rating=offensive_rating,
+        defensive_rating=defensive_rating,
+        box_plus_minus=box_plus_minus,
     )
 
 
@@ -1236,6 +1284,18 @@ def create_sportsreference_team_model(
     tackles: dict[str, int],
     interceptions: dict[str, int],
     clearances: dict[str, int],
+    free_throw_attempt_rate: dict[str, float],
+    offensive_rebound_percentage: dict[str, float],
+    defensive_rebound_percentage: dict[str, float],
+    total_rebound_percentage: dict[str, float],
+    assist_percentage: dict[str, float],
+    steal_percentage: dict[str, float],
+    block_percentage: dict[str, float],
+    turnover_percentage: dict[str, float],
+    usage_percentage: dict[str, float],
+    offensive_rating: dict[str, int],
+    defensive_rating: dict[str, int],
+    box_plus_minus: dict[str, float],
 ) -> TeamModel:
     """Create a team model from Sports Reference."""
     if not pytest_is_running.is_running():
@@ -1435,6 +1495,18 @@ def create_sportsreference_team_model(
             tackles=tackles,
             interceptions=interceptions,
             clearances=clearances,
+            free_throw_attempt_rate=free_throw_attempt_rate,
+            offensive_rebound_percentage=offensive_rebound_percentage,
+            defensive_rebound_percentage=defensive_rebound_percentage,
+            total_rebound_percentage=total_rebound_percentage,
+            assist_percentage=assist_percentage,
+            steal_percentage=steal_percentage,
+            block_percentage=block_percentage,
+            turnover_percentage=turnover_percentage,
+            usage_percentage=usage_percentage,
+            offensive_rating=offensive_rating,
+            defensive_rating=defensive_rating,
+            box_plus_minus=box_plus_minus,
         )
     with session.cache_disabled():
         return _create_sportsreference_team_model(
@@ -1633,4 +1705,16 @@ def create_sportsreference_team_model(
             tackles=tackles,
             interceptions=interceptions,
             clearances=clearances,
+            free_throw_attempt_rate=free_throw_attempt_rate,
+            offensive_rebound_percentage=offensive_rebound_percentage,
+            defensive_rebound_percentage=defensive_rebound_percentage,
+            total_rebound_percentage=total_rebound_percentage,
+            assist_percentage=assist_percentage,
+            steal_percentage=steal_percentage,
+            block_percentage=block_percentage,
+            turnover_percentage=turnover_percentage,
+            usage_percentage=usage_percentage,
+            offensive_rating=offensive_rating,
+            defensive_rating=defensive_rating,
+            box_plus_minus=box_plus_minus,
         )
