@@ -22,6 +22,20 @@ class TestTeamModel(unittest.TestCase):
             coaches=[],
             lbw=None,
             end_dt=None,
+            runs=None,
+            wickets=None,
+            overs=None,
+            balls=None,
+            byes=None,
+            leg_byes=None,
+            wides=None,
+            no_balls=None,
+            penalties=None,
+            balls_per_over=None,
+            fours=None,
+            sixes=None,
+            catches=None,
+            catches_dropped=None,
             version=VERSION,
         )
 
